@@ -394,7 +394,7 @@ pub(crate) enum OctoFontIni {
     Eti660,
     Schip,
     Fish,
-    Kusaima,
+    AKouZ1,
 }
 
 impl From<crate::OctoFont> for OctoFontIni {
@@ -406,7 +406,7 @@ impl From<crate::OctoFont> for OctoFontIni {
             crate::OctoFont::Eti660 => Self::Eti660,
             crate::OctoFont::Schip => Self::Schip,
             crate::OctoFont::Fish => Self::Fish,
-            crate::OctoFont::Kusaima => Self::Kusaima,
+            crate::OctoFont::AKouZ1 => Self::AKouZ1,
         }
     }
 }
@@ -420,7 +420,7 @@ impl From<crate::OctoFontIni> for OctoFont {
             crate::OctoFontIni::Eti660 => Self::Eti660,
             crate::OctoFontIni::Schip => Self::Schip,
             crate::OctoFontIni::Fish => Self::Fish,
-            crate::OctoFontIni::Kusaima => Self::Kusaima,
+            crate::OctoFontIni::AKouZ1 => Self::AKouZ1,
         }
     }
 }
