@@ -537,9 +537,9 @@ pub enum OctoFont {
     /// Custom font used by the Fish'n'Chips CHIP-8 emulator. Contains small digits
     /// for 0–F and big digits (7x9 pixels) for 0–F.
     Fish,
-    /// Font designed by Kusaima, used by in the KChip-8 and FPChip-8 emulators. Contains small
+    /// Font designed by A-KouZ1, used by in the KChip-8 and FPChip-8 emulators. Contains small
     /// digits for 0–F and big digits for 0–F.
-    Kusaima,
+    AKouZ1,
 }
 
 /// The default font is Octo's font, as it's the modern standard and contains all hexadecimal digits
@@ -738,7 +738,7 @@ pub fn get_font_data(font: OctoFont) -> ([u8; 5 * 16], Option<Vec<u8>>) {
                 0xFE, 0x66, 0x62, 0x64, 0x7C, 0x64, 0x60, 0x60, 0xF0, 0x00, // F
             ]),
         ),
-        OctoFont::Kusaima => (
+        OctoFont::AKouZ1 => (
             [
                 0x60, 0x90, 0x90, 0x90, 0x60, // 0
                 0x20, 0x60, 0x20, 0x20, 0x70, // 1
